@@ -9,12 +9,13 @@ from typing import Union
 from .connection import CloudflareScraper
 from .connection import Response
 from .connection import get
-from .connection import stream_binary
 from .connection import get_robots
 from .connection import join_url
 from .connection import make_session
+from .connection import stream_binary
 from .exceptions import CrawlDelayError
 from .exceptions import DisallowedPath
+from .exceptions import Unauthorized
 from .journal import Journal
 from .parse import BeautifulSoup
 from .parse import check_page
@@ -40,6 +41,7 @@ class FAAPI:
         self.crawl_delay: float = float(self.robots.get("Crawl-delay", [1.0])[0])
         self.last_get: float = perf_counter() - self.crawl_delay
         self.raise_for_delay: bool = False
+        self.raise_for_unauthorized: bool = True
 
     def load_cookies(self, cookies: Union[list[dict[str, str]], CookieJar]):
         self.session = make_session(cookies)
@@ -72,10 +74,16 @@ class FAAPI:
         self.handle_delay()
         return get(self.session, path, **params)
 
-    def get_parsed(self, path: str, **params) -> Optional[BeautifulSoup]:
+    def get_parsed(self, path: str, *, skip_page_check: bool = False, skip_auth_check: bool = False, **params
+                   ) -> BeautifulSoup:
         response: Response = self.get(path, **params)
         response.raise_for_status()
-        return parse_page(response.text) if response.ok else None
+        page: BeautifulSoup = parse_page(response.text)
+        if not skip_page_check:
+            check_page_raise(page)
+        if not skip_auth_check and self.raise_for_unauthorized and not parse_loggedin_user(page):
+            raise Unauthorized("Not logged in")
+        return page
 
     def me(self) -> Optional[User]:
         return self.user(user) if (user := parse_loggedin_user(self.get_parsed("login"))) else None
@@ -98,7 +106,7 @@ class FAAPI:
 
     # noinspection DuplicatedCode
     def gallery(self, user: str, page: int = 1) -> tuple[list[SubmissionPartial], int]:
-        check_page_raise(page_parsed := self.get_parsed(join_url("gallery", username_url(user), int(page))))
+        page_parsed: BeautifulSoup = self.get_parsed(join_url("gallery", username_url(user), int(page)))
         info_parsed: dict[str, Any] = parse_user_submissions(page_parsed)
         for s in (submissions := list(map(SubmissionPartial, info_parsed["figures"]))):
             s.author.status, s.author.title, s.author.join_date, s.author.user_icon_url = [
@@ -109,7 +117,7 @@ class FAAPI:
 
     # noinspection DuplicatedCode
     def scraps(self, user: str, page: int = 1) -> tuple[list[SubmissionPartial], int]:
-        check_page_raise(page_parsed := self.get_parsed(join_url("scraps", username_url(user), int(page))))
+        page_parsed: BeautifulSoup = self.get_parsed(join_url("scraps", username_url(user), int(page)))
         info_parsed: dict[str, Any] = parse_user_submissions(page_parsed)
         for s in (submissions := list(map(SubmissionPartial, info_parsed["figures"]))):
             s.author.status, s.author.title, s.author.join_date, s.author.user_icon_url = [
@@ -119,13 +127,13 @@ class FAAPI:
         return submissions, (page + 1) * (not info_parsed["last_page"])
 
     def favorites(self, user: str, page: str = "") -> tuple[list[SubmissionPartial], str]:
-        check_page_raise(page_parsed := self.get_parsed(join_url("favorites", username_url(user), page.strip())))
+        page_parsed: BeautifulSoup = self.get_parsed(join_url("favorites", username_url(user), page.strip()))
         info_parsed: dict[str, Any] = parse_user_favorites(page_parsed)
         submissions: list[SubmissionPartial] = list(map(SubmissionPartial, info_parsed["figures"]))
         return submissions, info_parsed["next_page"]
 
     def journals(self, user: str, page: int = 1) -> tuple[list[Journal], int]:
-        check_page_raise(page_parsed := self.get_parsed(join_url("journals", username_url(user), int(page))))
+        page_parsed: BeautifulSoup = self.get_parsed(join_url("journals", username_url(user), int(page)))
         info_parsed: dict[str, Any] = parse_user_journals(page_parsed)
         for j in (journals := list(map(Journal, info_parsed["sections"]))):
             j.author.name, j.author.status, j.author.title, j.author.join_date, j.author.user_icon_url = [
@@ -136,14 +144,15 @@ class FAAPI:
         return journals, (page + 1) * (not info_parsed["last_page"])
 
     def search(self, q: str, page: int = 1, **params) -> tuple[list[SubmissionPartial], int, int, int, int]:
-        check_page_raise(page_parsed := self.get_parsed("search", q=q, page=(page := int(page)), **params))
+        page_parsed: BeautifulSoup = self.get_parsed("search", q=q, page=(page := int(page)), **params)
         info_parsed: dict[str, Any] = parse_search_submissions(page_parsed)
         return (list(map(SubmissionPartial, info_parsed["figures"])), (page + 1) * (not info_parsed["last_page"]),
                 info_parsed["from"], info_parsed["to"], info_parsed["total"])
 
     def watchlist_to(self, user: str, page: int = 1) -> tuple[list[UserPartial], int]:
         users: list[UserPartial] = []
-        us, np = parse_watchlist(self.get_parsed(join_url("watchlist", "to", username_url(user), page)))
+        us, np = parse_watchlist(
+            self.get_parsed(join_url("watchlist", "to", username_url(user), page), skip_auth_check=True))
         for s, u in us:
             user: UserPartial = UserPartial()
             user.name = u
@@ -153,7 +162,8 @@ class FAAPI:
 
     def watchlist_by(self, user: str, page: int = 1) -> tuple[list[UserPartial], int]:
         users: list[UserPartial] = []
-        us, np = parse_watchlist(self.get_parsed(join_url("watchlist", "by", username_url(user), page)))
+        us, np = parse_watchlist(
+            self.get_parsed(join_url("watchlist", "by", username_url(user), page), skip_auth_check=True))
         for s, u in us:
             user: UserPartial = UserPartial()
             user.name = u
